@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2012-2022 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of Postorius.
 #
@@ -35,48 +35,88 @@ class ListMembersAccessTest(ViewTestCase):
         self.domain = self.mm_client.create_domain('example.com')
         self.foo_list = self.domain.create_list('foo')
         self.user = User.objects.create_user(
-            'testuser', 'test@example.com', 'testpass')
+            'testuser', 'test@example.com', 'testpass'
+        )
         self.superuser = User.objects.create_superuser(
-            'testsu', 'su@example.com', 'testpass')
+            'testsu', 'su@example.com', 'testpass'
+        )
         self.owner = User.objects.create_user(
-            'testowner', 'owner@example.com', 'testpass')
+            'testowner', 'owner@example.com', 'testpass'
+        )
         self.moderator = User.objects.create_user(
-            'testmoderator', 'moderator@example.com', 'testpass')
+            'testmoderator', 'moderator@example.com', 'testpass'
+        )
         for user in (self.user, self.superuser, self.owner, self.moderator):
             EmailAddress.objects.create(
-                user=user, email=user.email, verified=True)
+                user=user, email=user.email, verified=True
+            )
         self.foo_list.add_owner('owner@example.com')
         self.foo_list.add_moderator('moderator@example.com')
 
     def test_page_not_accessible_if_not_logged_in(self):
         for role in ['owner', 'moderator', 'member', 'nonmember']:
-            response = self.client.get(reverse(
-                'list_members', args=('foo.example.com', role,)))
+            response = self.client.get(
+                reverse(
+                    'list_members',
+                    args=(
+                        'foo.example.com',
+                        role,
+                    ),
+                )
+            )
             self.assertEqual(response.status_code, 403)
 
     def test_page_not_accessible_for_unprivileged_users(self):
         self.client.login(username='testuser', password='testpass')
         for role in ['owner', 'moderator', 'member', 'nonmember']:
-            response = self.client.get(reverse(
-                'list_members', args=('foo.example.com', role,)))
+            response = self.client.get(
+                reverse(
+                    'list_members',
+                    args=(
+                        'foo.example.com',
+                        role,
+                    ),
+                )
+            )
             self.assertEqual(response.status_code, 403)
 
     def test_not_accessible_for_moderator(self):
         self.client.login(username='testmoderator', password='testpass')
-        response = self.client.get(reverse(
-            'list_members', args=('foo.example.com', 'member',)))
+        response = self.client.get(
+            reverse(
+                'list_members',
+                args=(
+                    'foo.example.com',
+                    'member',
+                ),
+            )
+        )
         self.assertEqual(response.status_code, 403)
 
     def test_page_accessible_for_superuser(self):
         self.client.login(username='testsu', password='testpass')
-        response = self.client.get(reverse(
-            'list_members', args=('foo.example.com', 'member',)))
+        response = self.client.get(
+            reverse(
+                'list_members',
+                args=(
+                    'foo.example.com',
+                    'member',
+                ),
+            )
+        )
         self.assertEqual(response.status_code, 200)
 
     def test_page_accessible_for_owner(self):
         self.client.login(username='testowner', password='testpass')
-        response = self.client.get(reverse(
-            'list_members', args=('foo.example.com', 'member',)))
+        response = self.client.get(
+            reverse(
+                'list_members',
+                args=(
+                    'foo.example.com',
+                    'member',
+                ),
+            )
+        )
         self.assertEqual(response.status_code, 200)
 
 
@@ -91,22 +131,31 @@ class AddRemoveOwnerTest(ViewTestCase):
         self.mm_client = self.mm_client
         self.domain = self.mm_client.create_domain('example.com')
         self.foo_list = self.domain.create_list('foo')
-        self.su = User.objects.create_superuser(
-            'su', 'su@example.com', 'pwd')
+        self.su = User.objects.create_superuser('su', 'su@example.com', 'pwd')
         EmailAddress.objects.create(
-            user=self.su, email=self.su.email, verified=True)
+            user=self.su, email=self.su.email, verified=True
+        )
         self.client.login(username='su', password='pwd')
         self.mm_client.get_list('foo.example.com').add_owner('su@example.com')
 
     def test_add_remove_owner(self):
-        url = reverse('list_members', args=('foo.example.com', 'owner',))
+        url = reverse(
+            'list_members',
+            args=(
+                'foo.example.com',
+                'owner',
+            ),
+        )
         response = self.client.post(url, {'email': 'newowner@example.com'})
         self.assertRedirects(response, url)
         owners_emails = [owner.email for owner in self.foo_list.owners]
         self.assertTrue('newowner@example.com' in owners_emails)
         self.client.post(
-            reverse('remove_role', args=('foo.example.com', 'owner',
-                                         'newowner@example.com')))
+            reverse(
+                'remove_role',
+                args=('foo.example.com', 'owner', 'newowner@example.com'),
+            )
+        )
         owners_emails = [owner.email for owner in self.foo_list.owners]
         self.assertFalse('newowner@example.com' in owners_emails)
 
@@ -117,14 +166,23 @@ class AddRemoveOwnerTest(ViewTestCase):
         self.su.is_superuser = False
         self.su.save()
         # It must still be allowed to create and remove owners
-        url = reverse('list_members', args=('foo.example.com', 'owner',))
+        url = reverse(
+            'list_members',
+            args=(
+                'foo.example.com',
+                'owner',
+            ),
+        )
         response = self.client.post(url, {'email': 'newowner@example.com'})
         self.assertRedirects(response, url)
         owners_emails = [owner.email for owner in self.foo_list.owners]
         self.assertTrue('newowner@example.com' in owners_emails)
         response = self.client.post(
-            reverse('remove_role', args=('foo.example.com', 'owner',
-                                         'newowner@example.com')))
+            reverse(
+                'remove_role',
+                args=('foo.example.com', 'owner', 'newowner@example.com'),
+            )
+        )
         self.assertHasSuccessMessage(response)
         owners_emails = [owner.email for owner in self.foo_list.owners]
         self.assertFalse('newowner@example.com' in owners_emails)
@@ -138,8 +196,11 @@ class AddRemoveOwnerTest(ViewTestCase):
         self.assertTrue('su@example.com' in owners_emails)
         self.assertTrue('otherowner@example.com' in owners_emails)
         response = self.client.post(
-            reverse('remove_role', args=('foo.example.com', 'owner',
-                                         'su@example.com')))
+            reverse(
+                'remove_role',
+                args=('foo.example.com', 'owner', 'su@example.com'),
+            )
+        )
         self.assertEqual(response.status_code, 302)
         self.assertHasSuccessMessage(response)
         owners_emails = [owner.email for owner in mm_list.owners]
@@ -151,8 +212,11 @@ class AddRemoveOwnerTest(ViewTestCase):
         self.assertTrue('su@example.com' in owners_emails)
         self.assertFalse('otherowner@example.com' in owners_emails)
         response = self.client.post(
-            reverse('remove_role', args=('foo.example.com', 'owner',
-                                         'su@example.com')))
+            reverse(
+                'remove_role',
+                args=('foo.example.com', 'owner', 'su@example.com'),
+            )
+        )
         self.assertEqual(response.status_code, 302)
         self.assertHasErrorMessage(response)
         owners_emails = [owner.email for owner in mm_list.owners]
@@ -169,13 +233,19 @@ class AddModeratorTest(ViewTestCase):
         super(AddModeratorTest, self).setUp()
         self.domain = self.mm_client.create_domain('example.com')
         self.foo_list = self.domain.create_list('foo')
-        self.su = User.objects.create_superuser(
-            'su', 'su@example.com', 'pwd')
+        self.su = User.objects.create_superuser('su', 'su@example.com', 'pwd')
         EmailAddress.objects.create(
-            user=self.su, email=self.su.email, verified=True)
+            user=self.su, email=self.su.email, verified=True
+        )
         # login and post new moderator data to url
         self.client.login(username='su', password='pwd')
-        url = reverse('list_members', args=('foo.example.com', 'moderator',))
+        url = reverse(
+            'list_members',
+            args=(
+                'foo.example.com',
+                'moderator',
+            ),
+        )
         response = self.client.post(url, {'email': 'newmod@example.com'})
         self.assertRedirects(response, url)
 
@@ -197,9 +267,11 @@ class ListMembersTest(ViewTestCase):
         self.domain = self.mm_client.create_domain('example.com')
         self.foo_list = self.domain.create_list('foo')
         self.superuser = User.objects.create_superuser(
-            'testsu', 'su@example.com', 'testpass')
+            'testsu', 'su@example.com', 'testpass'
+        )
         EmailAddress.objects.create(
-            user=self.superuser, email=self.superuser.email, verified=True)
+            user=self.superuser, email=self.superuser.email, verified=True
+        )
 
     def tearDown(self):
         self.foo_list.delete()
@@ -209,13 +281,20 @@ class ListMembersTest(ViewTestCase):
     def test_show_members_page(self):
         self.client.login(username='testsu', password='testpass')
         member_1 = self.foo_list.subscribe(
-            'member-1@example.com', pre_verified=True, pre_confirmed=True,
-            pre_approved=True)
+            'member-1@example.com',
+            pre_verified=True,
+            pre_confirmed=True,
+            pre_approved=True,
+        )
         member_2 = self.foo_list.subscribe(
-            'member-2@example.com', pre_verified=True, pre_confirmed=True,
-            pre_approved=True)
-        response = self.client.get(reverse(
-            'list_members', args=['foo.example.com', 'member']))
+            'member-2@example.com',
+            pre_verified=True,
+            pre_confirmed=True,
+            pre_approved=True,
+        )
+        response = self.client.get(
+            reverse('list_members', args=['foo.example.com', 'member'])
+        )
         self.assertEqual(response.status_code, 200)
         self.assertEqual(len(response.context['members']), 2)
         self.assertEqual(response.context['members'].paginator.count, 2)
@@ -227,70 +306,93 @@ class ListMembersTest(ViewTestCase):
         """Test that Members's delivery related settings/preferences."""
         self.client.login(username='testsu', password='testpass')
         member_1 = self.foo_list.subscribe(
-            'member-1@example.com', pre_verified=True, pre_confirmed=True,
-            pre_approved=True)
+            'member-1@example.com',
+            pre_verified=True,
+            pre_confirmed=True,
+            pre_approved=True,
+        )
         member_1.delivery_mode = 'plaintext_digests'
         member_1.moderation_action = 'hold'
         member_1.save()
         member_2 = self.foo_list.subscribe(
-            'member-2@example.com', pre_verified=True, pre_confirmed=True,
-            pre_approved=True)
+            'member-2@example.com',
+            pre_verified=True,
+            pre_confirmed=True,
+            pre_approved=True,
+        )
         member_2.delivery_mode = 'summary_digests'
         member_2.moderation_action = 'defer'
         member_2.save()
-        response = self.client.get(reverse(
-            'list_members', args=['foo.example.com', 'member']))
+        response = self.client.get(
+            reverse('list_members', args=['foo.example.com', 'member'])
+        )
         self.assertEqual(response.status_code, 200)
         self.assertEqual(len(response.context['members']), 2)
         for each in (
-                # Delivery mode settings.
-                'Plain Text Digests', 'Summary Digests',
-                # Moderatation action settings.
-                'Hold for moderation', 'Default processing'):
+            # Delivery mode settings.
+            'Plain Text Digests',
+            'Summary Digests',
+            # Moderatation action settings.
+            'Hold for moderation',
+            'Default processing',
+        ):
             self.assertContains(response, each)
 
     def test_search_members_1(self):
         self.client.login(username='testsu', password='testpass')
         member_1 = self.foo_list.subscribe(
-            'member-1@example.com', pre_verified=True, pre_confirmed=True,
-            pre_approved=True)
+            'member-1@example.com',
+            pre_verified=True,
+            pre_confirmed=True,
+            pre_approved=True,
+        )
         member_2 = self.foo_list.subscribe(
-            'member-2@example.com', pre_verified=True, pre_confirmed=True,
-            pre_approved=True)
-        response = self.client.get(reverse(
-            'list_members', args=['foo.example.com', 'member']),
-            {'q': 'example.com'})
+            'member-2@example.com',
+            pre_verified=True,
+            pre_confirmed=True,
+            pre_approved=True,
+        )
+        response = self.client.get(
+            reverse('list_members', args=['foo.example.com', 'member']),
+            {'q': 'example.com'},
+        )
         self.assertEqual(response.status_code, 200)
         self.assertEqual(len(response.context['members']), 2)
         self.assertContains(response, member_1.email)
         self.assertContains(response, member_2.email)
         self.assertContains(response, '<small>(2)</small>')
-        response = self.client.get(reverse(
-            'list_members', args=['foo.example.com', 'member']),
-            {'q': 'member-1'})
+        response = self.client.get(
+            reverse('list_members', args=['foo.example.com', 'member']),
+            {'q': 'member-1'},
+        )
         self.assertEqual(response.status_code, 200)
         self.assertEqual(len(response.context['members']), 1)
         self.assertContains(response, member_1.email)
         self.assertNotContains(response, member_2.email)
         self.assertContains(response, '<small>(1)</small>')
-        response = self.client.get(reverse(
-            'list_members', args=['foo.example.com', 'member']),
-            {'q': 'not_a_member'})
+        response = self.client.get(
+            reverse('list_members', args=['foo.example.com', 'member']),
+            {'q': 'not_a_member'},
+        )
         self.assertEqual(response.status_code, 200)
         self.assertEqual(len(response.context['members']), 0)
         self.assertNotContains(response, member_1.email)
         self.assertNotContains(response, member_2.email)
         self.assertContains(response, '<small>(0)</small>')
-        self.assertEqual(response.context['empty_error'],
-                         'No members were found matching the search.')
+        self.assertEqual(
+            response.context['empty_error'],
+            'No members were found matching the search.',
+        )
         self.foo_list.unsubscribe('member-1@example.com')
         self.foo_list.unsubscribe('member-2@example.com')
-        response = self.client.get(reverse(
-            'list_members', args=['foo.example.com', 'member']))
+        response = self.client.get(
+            reverse('list_members', args=['foo.example.com', 'member'])
+        )
         self.assertEqual(response.status_code, 200)
         self.assertEqual(len(response.context['members']), 0)
-        self.assertEqual(response.context['empty_error'],
-                         'List has no members')
+        self.assertEqual(
+            response.context['empty_error'], 'List has no members'
+        )
         self.assertContains(response, '<small>(0)</small>')
 
 
@@ -302,9 +404,11 @@ class ListNonMembersTest(ViewTestCase):
         self.domain = self.mm_client.create_domain('example.com')
         self.foo_list = self.domain.create_list('foo')
         self.superuser = User.objects.create_superuser(
-            'testsu', 'su@example.com', 'testpass')
+            'testsu', 'su@example.com', 'testpass'
+        )
         EmailAddress.objects.create(
-            user=self.superuser, email=self.superuser.email, verified=True)
+            user=self.superuser, email=self.superuser.email, verified=True
+        )
 
     def tearDown(self):
         self.foo_list.delete()
@@ -314,13 +418,17 @@ class ListNonMembersTest(ViewTestCase):
     def test_show_nonmembers(self):
         self.client.login(username='testsu', password='testpass')
         self.foo_list.add_role(
-            address='nonmember-1@example.com', role='nonmember')
+            address='nonmember-1@example.com', role='nonmember'
+        )
         self.foo_list.add_role(
-            address='nonmember-2@example.com', role='nonmember')
+            address='nonmember-2@example.com', role='nonmember'
+        )
         self.foo_list.add_role(
-            address='nonmember-3@example.com', role='nonmember')
-        response = self.client.get(reverse(
-            'list_members', args=['foo.example.com', 'nonmember']))
+            address='nonmember-3@example.com', role='nonmember'
+        )
+        response = self.client.get(
+            reverse('list_members', args=['foo.example.com', 'nonmember'])
+        )
         self.assertEqual(response.status_code, 200)
         self.assertEqual(len(response.context['members']), 3)
         self.assertEqual(response.context['members'].paginator.count, 3)
@@ -332,25 +440,32 @@ class ListNonMembersTest(ViewTestCase):
     def test_search_nonmembers(self):
         self.client.login(username='testsu', password='testpass')
         self.foo_list.add_role(
-            address='nonmember-1@example.com', role='nonmember')
+            address='nonmember-1@example.com', role='nonmember'
+        )
         self.foo_list.add_role(
-            address='nonmember-2@example.com', role='nonmember')
+            address='nonmember-2@example.com', role='nonmember'
+        )
         self.foo_list.add_role(
-            address='nonmember-3@example.com', role='nonmember')
-        response = self.client.get(reverse(
-            'list_members', args=['foo.example.com', 'nonmember']),
-            {'q': '2@example.com'})
+            address='nonmember-3@example.com', role='nonmember'
+        )
+        response = self.client.get(
+            reverse('list_members', args=['foo.example.com', 'nonmember']),
+            {'q': '2@example.com'},
+        )
         self.assertEqual(response.status_code, 200)
         self.assertEqual(len(response.context['members']), 1)
         self.assertContains(response, 'nonmember-2@example.com')
         self.assertContains(response, '<small>(1)</small>')
-        response = self.client.get(reverse(
-            'list_members', args=['foo.example.com', 'nonmember']),
-            {'q': 'random_query'})
+        response = self.client.get(
+            reverse('list_members', args=['foo.example.com', 'nonmember']),
+            {'q': 'random_query'},
+        )
         self.assertEqual(response.status_code, 200)
         self.assertEqual(len(response.context['members']), 0)
-        self.assertEqual(response.context['empty_error'],
-                         'No nonmembers were found matching the search.')
+        self.assertEqual(
+            response.context['empty_error'],
+            'No nonmembers were found matching the search.',
+        )
         self.assertContains(response, '<small>(0)</small>')
 
     def test_add_nonmember(self):
@@ -358,34 +473,56 @@ class ListNonMembersTest(ViewTestCase):
         # Check that there aren't any nonmembers.
         self.assertEqual(len(self.foo_list.nonmembers), 0)
         # Add a new nonmember.
-        url = reverse('list_members', args=('foo.example.com', 'nonmember',))
-        response = self.client.post(url,
-                                    {'email': 'new.nonmember@example.com'})
+        url = reverse(
+            'list_members',
+            args=(
+                'foo.example.com',
+                'nonmember',
+            ),
+        )
+        response = self.client.post(
+            url, {'email': 'new.nonmember@example.com'}
+        )
         self.assertRedirects(response, url)
-        response = self.client.get(reverse(
-            'list_members', args=['foo.example.com', 'nonmember']))
+        response = self.client.get(
+            reverse('list_members', args=['foo.example.com', 'nonmember'])
+        )
         self.assertEqual(response.status_code, 200)
         self.assertEqual(len(response.context['members']), 1)
-        self.assertEqual(response.context['members'][0].email,
-                         'new.nonmember@example.com')
+        self.assertEqual(
+            response.context['members'][0].email, 'new.nonmember@example.com'
+        )
 
     def test_nonmember_delete(self):
         self.client.login(username='testsu', password='testpass')
         self.foo_list.add_role(
-            address='nonmember-1@example.com', role='nonmember')
+            address='nonmember-1@example.com', role='nonmember'
+        )
         self.foo_list.add_role(
-            address='nonmember-2@example.com', role='nonmember')
+            address='nonmember-2@example.com', role='nonmember'
+        )
         self.foo_list.add_role(
-            address='nonmember-3@example.com', role='nonmember')
+            address='nonmember-3@example.com', role='nonmember'
+        )
         nonmember_emails = [nm.email for nm in self.foo_list.nonmembers]
         self.assertEqual(
             sorted(nonmember_emails),
-            ['nonmember-1@example.com',
-             'nonmember-2@example.com',
-             'nonmember-3@example.com'])
+            [
+                'nonmember-1@example.com',
+                'nonmember-2@example.com',
+                'nonmember-3@example.com',
+            ],
+        )
         response = self.client.post(
-            reverse('remove_role', args=(
-                'foo.example.com', 'nonmember', 'nonmember-1@example.com')))
+            reverse(
+                'remove_role',
+                args=(
+                    'foo.example.com',
+                    'nonmember',
+                    'nonmember-1@example.com',
+                ),
+            )
+        )
         self.assertEqual(response.status_code, 302)
         self.assertHasSuccessMessage(response)
         nonmember_emails = [nm.email for nm in self.foo_list.nonmembers]
@@ -394,15 +531,16 @@ class ListNonMembersTest(ViewTestCase):
 
 
 class TestMassRemoval(ViewTestCase):
-
     def setUp(self):
         super().setUp()
         self.domain = self.mm_client.create_domain('example.com')
         self.foo_list = self.domain.create_list('foo')
         self.superuser = User.objects.create_superuser(
-            'testsu', 'su@example.com', 'testpass')
+            'testsu', 'su@example.com', 'testpass'
+        )
         EmailAddress.objects.create(
-            user=self.superuser, email=self.superuser.email, verified=True)
+            user=self.superuser, email=self.superuser.email, verified=True
+        )
         self.client.login(username='testsu', password='testpass')
 
     def tearDown(self):
@@ -416,13 +554,17 @@ class TestMassRemoval(ViewTestCase):
             member = f'member-{count}@example.com'
             member_list.append(member)
             self.foo_list.subscribe(
-                member, pre_verified=True, pre_confirmed=True,
-                pre_approved=True)
+                member,
+                pre_verified=True,
+                pre_confirmed=True,
+                pre_approved=True,
+            )
         # Also, add an invalid address.
         member_list.append('member@member@example.com')
         self.assertEqual(len(self.foo_list.members), 100)
         response = self.client.post(
-            reverse('mass_removal', args=('foo.example.com', )),
-            data=dict(emails='\n'.join(member_list)))
+            reverse('mass_removal', args=('foo.example.com',)),
+            data=dict(emails='\n'.join(member_list)),
+        )
         self.assertEqual(response.status_code, 302)
         self.assertEqual(len(self.foo_list.members), 0)
