@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 1998-2019 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of Postorius.
 #
@@ -18,24 +18,43 @@
 
 
 import logging
-from django.utils.six.moves.urllib.error import HTTPError
+from urllib.error import HTTPError
 
-from allauth.account.models import EmailAddress
-from django.forms import formset_factory
 from django.contrib import messages
 from django.contrib.auth.decorators import login_required
-from django.shortcuts import render
+from django.contrib.auth.forms import AdminPasswordChangeForm
+from django.forms import formset_factory
+from django.http import Http404
+from django.shortcuts import redirect, render
+from django.urls import reverse, reverse_lazy
 from django.utils.decorators import method_decorator
 from django.utils.translation import gettext as _
-from django.urls import reverse, reverse_lazy
+from django.views.decorators.debug import sensitive_post_parameters
+from django.views.decorators.http import require_GET
 from django.views.generic import FormView
-from django.http import Http404
 
-from postorius.models import List, MailmanUser
+from allauth.account.models import EmailAddress
+from django_mailman3.lib.mailman import get_mailman_client, get_mailman_user
+from django_mailman3.lib.paginator import MailmanPaginator, paginate
+
+from postorius.auth.decorators import superuser_required
 from postorius.forms import (
-    UserPreferences, UserPreferencesFormset, ChangeSubscriptionForm)
+    ChangeSubscriptionForm,
+    ManageAddressForm,
+    ManageAddressFormSet,
+    ManageMemberForm,
+    ManageMemberFormSet,
+    ManageUserForm,
+    UserPreferences,
+    UserPreferencesFormset,
+)
+from postorius.models import List, SubscriptionMode
+from postorius.utils import (
+    filter_memberships_by_roles,
+    get_django_user,
+    set_preferred,
+)
 from postorius.views.generic import MailmanClientMixin
-from django_mailman3.lib.mailman import get_mailman_client
 
 
 logger = logging.getLogger(__name__)
@@ -46,6 +65,10 @@ class UserPreferencesView(FormView, MailmanClientMixin):
 
     form_class = UserPreferences
 
+    #: Disabled delivery_status choices that a subscriber cannot set. This is
+    #: different from what an admi is allowed to set.
+    delivery_status_disabled_fields = ['by_moderator', 'by_bounces']
+
     def get_context_data(self, **kwargs):
         data = super(UserPreferencesView, self).get_context_data(**kwargs)
         data['mm_user'] = self.mm_user
@@ -54,17 +77,21 @@ class UserPreferencesView(FormView, MailmanClientMixin):
     def get_form_kwargs(self):
         kwargs = super(UserPreferencesView, self).get_form_kwargs()
         kwargs['preferences'] = self._get_preferences()
+        # Disable the choice of by_admin and by_bounces for a user.
+        kwargs[
+            'disabled_delivery_choices'
+        ] = self.delivery_status_disabled_fields
         return kwargs
 
     def _set_view_attributes(self, request, *args, **kwargs):
-        self.mm_user = MailmanUser.objects.get_or_create_from_django(
-            request.user)
+        self.mm_user = get_mailman_user(request.user)
 
     @method_decorator(login_required)
     def dispatch(self, request, *args, **kwargs):
         self._set_view_attributes(request, *args, **kwargs)
         return super(UserPreferencesView, self).dispatch(
-            request, *args, **kwargs)
+            request, *args, **kwargs
+        )
 
     def form_valid(self, form):
         try:
@@ -73,7 +100,8 @@ class UserPreferencesView(FormView, MailmanClientMixin):
             messages.error(self.request, e.msg)
         if form.has_changed():
             messages.success(
-                self.request, _('Your preferences have been updated.'))
+                self.request, _('Your preferences have been updated.')
+            )
         else:
             messages.info(self.request, _('Your preferences did not change.'))
         return super(UserPreferencesView, self).form_valid(form)
@@ -90,7 +118,7 @@ class UserMailmanSettingsView(UserPreferencesView):
         # Get the defaults and pre-populate so view shows them
         combinedpreferences = self._get_combined_preferences()
         for key in combinedpreferences:
-            if key != "self_link":
+            if key != 'self_link':
                 self.mm_user.preferences[key] = combinedpreferences[key]
 
         # This is a bit of a hack so preferences behave as users expect
@@ -107,15 +135,15 @@ class UserMailmanSettingsView(UserPreferencesView):
         defaultpreferences = get_mailman_client().preferences
         combinedpreferences = {}
         for key in defaultpreferences:
-            if key != "self_link":
+            if key != 'self_link':
                 combinedpreferences[key] = defaultpreferences[key]
 
         # Clobber defaults with any preferences already set
         for key in self.mm_user.preferences:
-            if key != "self_link":
+            if key != 'self_link':
                 combinedpreferences[key] = self.mm_user.preferences[key]
 
-        return(combinedpreferences)
+        return combinedpreferences
 
 
 class UserAddressPreferencesView(UserPreferencesView):
@@ -126,7 +154,8 @@ class UserAddressPreferencesView(UserPreferencesView):
 
     def get_form_class(self):
         return formset_factory(
-            UserPreferences, formset=UserPreferencesFormset, extra=0)
+            UserPreferences, formset=UserPreferencesFormset, extra=0
+        )
 
     def _get_preferences(self):
         return [address.preferences for address in self.mm_user.addresses]
@@ -147,33 +176,35 @@ class UserAddressPreferencesView(UserPreferencesView):
 
             # initialize with default preferences
             for key in defaultpreferences:
-                if key != "self_link":
+                if key != 'self_link':
                     prefs[key] = defaultpreferences[key]
 
             # overwrite with user's global preferences
             for key in globalpreferences:
-                if key != "self_link":
+                if key != 'self_link':
                     prefs[key] = globalpreferences[key]
 
             # overwrite with address-specific preferences
             for key in address.preferences:
-                if key != "self_link":
+                if key != 'self_link':
                     prefs[key] = address.preferences[key]
             combinedpreferences.append(prefs)
 
             # put the combined preferences back on the original object
             for key in prefs:
-                if key != "self_link":
+                if key != 'self_link':
                     address.preferences[key] = prefs[key]
 
         return combinedpreferences
 
     def get_context_data(self, **kwargs):
         data = super(UserAddressPreferencesView, self).get_context_data(
-            **kwargs)
+            **kwargs
+        )
         data['formset'] = data.pop('form')
-        for form, address in list(zip(
-                data['formset'].forms, self.mm_user.addresses)):
+        for form, address in list(
+            zip(data['formset'].forms, self.mm_user.addresses)
+        ):
             form.address = address
         return data
 
@@ -184,10 +215,14 @@ class UserListOptionsView(UserPreferencesView):
     form_class = UserPreferences
     template_name = 'postorius/user/list_options.html'
 
-    def _get_subscription(self):
+    def _get_subscription(self, member_id):
         subscription = None
+        # We *could* use the find_members API, but then we'd have to
+        # authenticate that the found subscription belongs to the currently
+        # logged-in user otherwise. That might be a faster choice, but this
+        # page isn't that slow right now.
         for s in self.mm_user.subscriptions:
-            if s.role == 'member' and s.list_id == self.mlist.list_id:
+            if s.role == 'member' and s.member_id == member_id:
                 subscription = s
                 break
         if not subscription:
@@ -196,9 +231,20 @@ class UserListOptionsView(UserPreferencesView):
 
     def _set_view_attributes(self, request, *args, **kwargs):
         super(UserListOptionsView, self)._set_view_attributes(
-            request, *args, **kwargs)
-        self.mlist = List.objects.get_or_404(fqdn_listname=kwargs['list_id'])
-        self.subscription = self._get_subscription()
+            request, *args, **kwargs
+        )
+        self.member_id = kwargs.get('member_id')
+        self.subscription = self._get_subscription(self.member_id)
+        self.mlist = List.objects.get_or_404(
+            fqdn_listname=self.subscription.list_id
+        )
+        if (
+            self.subscription.subscription_mode
+            == SubscriptionMode.as_user.name
+        ):
+            self.subscriber = self.subscription.user.user_id
+        else:
+            self.subscriber = self.subscription.email
 
     def _get_preferences(self):
         return self.subscription.preferences
@@ -206,16 +252,32 @@ class UserListOptionsView(UserPreferencesView):
     def get_context_data(self, **kwargs):
         data = super(UserListOptionsView, self).get_context_data(**kwargs)
         data['mlist'] = self.mlist
-        user_emails = EmailAddress.objects.filter(
-            user=self.request.user, verified=True).order_by(
-            "email").values_list("email", flat=True)
+        user_emails = (
+            EmailAddress.objects.filter(user=self.request.user, verified=True)
+            .order_by('email')
+            .values_list('email', flat=True)
+        )
+        mm_user = get_mailman_user(self.request.user)
+        primary_email = None
+        if mm_user.preferred_address is None:
+            primary_email = set_preferred(self.request.user, mm_user)
+        else:
+            primary_email = mm_user.preferred_address.email
         data['change_subscription_form'] = ChangeSubscriptionForm(
-            user_emails, initial={'email': self.subscription.email})
+            user_emails,
+            mm_user.user_id,
+            primary_email,
+            initial={
+                'subscriber': self.subscriber,
+                'member_id': self.member_id,
+            },
+        )
         return data
 
     def get_success_url(self):
         return reverse(
-            'user_list_options', kwargs=dict(list_id=self.mlist.list_id))
+            'user_list_options', kwargs=dict(member_id=self.member_id)
+        )
 
 
 class UserSubscriptionPreferencesView(UserPreferencesView):
@@ -234,12 +296,14 @@ class UserSubscriptionPreferencesView(UserPreferencesView):
 
     def _set_view_attributes(self, request, *args, **kwargs):
         super(UserSubscriptionPreferencesView, self)._set_view_attributes(
-            request, *args, **kwargs)
+            request, *args, **kwargs
+        )
         self.subscriptions = self._get_subscriptions()
 
     def get_form_class(self):
         return formset_factory(
-            UserPreferences, formset=UserPreferencesFormset, extra=0)
+            UserPreferences, formset=UserPreferencesFormset, extra=0
+        )
 
     def _get_preferences(self):
         return [sub.preferences for sub in self.subscriptions]
@@ -260,12 +324,12 @@ class UserSubscriptionPreferencesView(UserPreferencesView):
 
             # initialize with default preferences
             for key in defaultpreferences:
-                if key != "self_link":
+                if key != 'self_link':
                     prefs[key] = defaultpreferences[key]
 
             # overwrite with user's global preferences
             for key in globalpreferences:
-                if key != "self_link":
+                if key != 'self_link':
                     prefs[key] = globalpreferences[key]
 
             # overwrite with address-based preferences
@@ -277,12 +341,12 @@ class UserSubscriptionPreferencesView(UserPreferencesView):
                     addresspreferences = address.preferences
 
             for key in addresspreferences:
-                if key != "self_link":
+                if key != 'self_link':
                     prefs[key] = addresspreferences[key]
 
             # overwrite with subscription-specific preferences
             for key in sub.preferences:
-                if key != "self_link":
+                if key != 'self_link':
                     prefs[key] = sub.preferences[key]
 
             combinedpreferences.append(prefs)
@@ -292,18 +356,151 @@ class UserSubscriptionPreferencesView(UserPreferencesView):
 
     def get_context_data(self, **kwargs):
         data = super(UserSubscriptionPreferencesView, self).get_context_data(
-            **kwargs)
+            **kwargs
+        )
         data['formset'] = data.pop('form')
-        for form, subscription in list(zip(
-                data['formset'].forms, self.subscriptions)):
+        for form, subscription in list(
+            zip(data['formset'].forms, self.subscriptions)
+        ):
             form.list_id = subscription.list_id
+            form.member_id = subscription.member_id
+            form.subscription_mode = subscription.subscription_mode
+            form.address = subscription.address
         return data
 
 
 @login_required
 def user_subscriptions(request):
     """Shows the subscriptions of a user."""
-    mm_user = MailmanUser.objects.get_or_create_from_django(request.user)
+    mm_user = get_mailman_user(request.user)
     memberships = [m for m in mm_user.subscriptions]
-    return render(request, 'postorius/user/subscriptions.html',
-                  {'memberships': memberships})
+    return render(
+        request,
+        'postorius/user/subscriptions.html',
+        {'memberships': memberships},
+    )
+
+
+@require_GET
+@superuser_required
+def list_users(request):
+    """List of all users."""
+    client = get_mailman_client()
+    query = request.GET.get('q')
+
+    if query:
+
+        def _find_users(count, page):
+            return client.find_users_page(query, count, page)
+
+        find_method = _find_users
+    else:
+        find_method = client.get_user_page
+
+    users = paginate(
+        find_method,
+        request.GET.get('page'),
+        request.GET.get('count'),
+        paginator_class=MailmanPaginator,
+    )
+    return render(
+        request,
+        'postorius/user/all.html',
+        {'all_users': users, 'query': query},
+    )
+
+
+@superuser_required
+@sensitive_post_parameters('password1', 'password2')
+def manage_user(request, user_id):
+    """Manage a single Mailman user view."""
+    client = get_mailman_client()
+    user = client.get_user(user_id)
+    user_form = ManageUserForm(user=user)
+    addr_formset = formset_factory(
+        ManageAddressForm, formset=ManageAddressFormSet, extra=0
+    )
+    sub_formset = formset_factory(
+        ManageMemberForm, formset=ManageMemberFormSet, extra=0
+    )
+    django_user = get_django_user(user)
+    addresses = addr_formset(addresses=user.addresses)
+    subscriptions = sub_formset(
+        members=filter_memberships_by_roles(
+            user.subscriptions, roles=['member', 'nonmember']
+        )
+    )
+
+    change_password = None
+    if django_user is not None:
+        change_password = AdminPasswordChangeForm(django_user)
+        # The form always grabs focus so stop it from doing that unless there
+        # is an error in the form submitted.
+        change_password.fields['password1'].widget.attrs['autofocus'] = False
+
+    if request.method == 'POST':
+        # There are 4 forms in this view page, which one was submitted is
+        # distinguished based on the name of the submit button.
+        if 'address_form' in request.POST:
+            # This is the 'addresses' form, built using addr_formset.
+            addresses = addr_formset(request.POST, addresses=user.addresses)
+            if addresses.is_valid():
+                updated = addresses.save()
+                if updated:
+                    messages.success(
+                        request,
+                        _('Successfully updated addresses {}').format(
+                            ', '.join(updated)
+                        ),
+                    )     # noqa: E501
+        elif 'subs_form' in request.POST:
+            # This is the 'subscriptions' form, built using sub_formset.
+            subscriptions = sub_formset(
+                request.POST, members=user.subscriptions
+            )
+            if subscriptions.is_valid():
+                updated = subscriptions.save()
+                if updated:
+                    messages.success(
+                        request,
+                        _('Successfully updated memberships for {}').format(
+                            ', '.join(updated)
+                        ),
+                    )  # noqa: E501
+        elif 'user_form' in request.POST:
+            # This is the 'user' form, built using ManageUserForm.
+            user_form = ManageUserForm(request.POST, user=user)
+            if user_form.is_valid():
+                user_form.save()
+                messages.success(request, _('Successfully updated user.'))
+        elif 'change_password' in request.POST:
+            change_password = AdminPasswordChangeForm(
+                django_user, request.POST
+            )
+            if change_password.is_valid():
+                change_password.save()
+                # This will log the user out, which we want because the admin
+                # is changing their password. In case of user changing their
+                # own passowrd, they can remain authenticated.
+                messages.success(request, _('Password updated successfully'))
+                # Stop the form from grabbing the passowrd if successfully
+                # updated.
+                change_password.fields['password1'].widget.attrs[
+                    'autofocus'
+                ] = False
+
+        return redirect(reverse('manage_user', args=(user_id,)))
+
+    # In case of GET request, return the formsets with initial data.
+    return render(
+        request,
+        'postorius/user/manage.html',
+        {
+            'auser': user,
+            'user_form': user_form,
+            'change_password': change_password,
+            'django_user': django_user,
+            'addresses': addresses,
+            'subscriptions': subscriptions,
+        },
+    )
